import { useCallback, useEffect, useState } from 'react';
import useWebSocket, { ReadyState } from 'react-use-websocket';
export const useWsApi = (wsApiUrl, route, options) => {
    const { onConnected, onResponse, onError, onDisconnected } = options;
    const [error, setError] = useState(false);
    const [connected, setConnected] = useState(false);
    const [request, setRequest] = useState();
    const handleConnected = useCallback(() => {
        setConnected(true);
        setError(false);
        onConnected?.();
    }, [onConnected]);
    const handleError = useCallback((error) => {
        setError(false);
        onError?.(error);
    }, [onError]);
    const handleResponse = useCallback((response) => {
        setError(false);
        onResponse?.(response);
    }, [onResponse]);
    const handleDisconnected = useCallback(() => {
        setConnected(false);
        onDisconnected?.();
    }, [onDisconnected]);
    const { readyState, lastJsonMessage, getWebSocket, sendMessage } = useWebSocket(wsApiUrl, {
        onOpen: () => handleConnected(),
        onError: (error) => handleError(error),
        onClose: () => handleDisconnected(),
    }, !!request);
    // send request
    useEffect(() => {
        if (request && readyState === ReadyState.OPEN) {
            sendMessage(JSON.stringify({
                action: route.action,
                request,
            }));
        }
    }, [request, readyState, route.action, sendMessage]);
    // response received
    useEffect(() => {
        if (!lastJsonMessage || JSON.stringify(lastJsonMessage) === '{}')
            return;
        handleResponse(lastJsonMessage);
    }, [lastJsonMessage, getWebSocket, handleResponse]);
    const sendRequest = useCallback((request) => {
        setConnected(true);
        setRequest(request);
    }, []);
    const disconnect = useCallback(() => {
        getWebSocket()?.close();
        handleDisconnected?.();
    }, [getWebSocket, handleDisconnected]);
    return {
        sendRequest,
        connected,
        error,
        disconnect,
    };
};
//# sourceMappingURL=useWsApi.js.map